@@ -1,5 +1,5 @@
 %# Copyright (C) 2006-2008, Thomas Treichl <treichl@users.sourceforge.net>
-%# OdePkg - A package for solving differential equations with GNU Octave
+%# OdePkg - A package for solving ordinary differential equations and more
 %#
 %# This program is free software; you can redistribute it and/or modify
 %# it under the terms of the GNU General Public License as published by
@@ -58,7 +58,7 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
   elseif (nargin < 3)
     print_usage;
 
-  elseif (~isa (vfun, 'function_handle'))
+  elseif ~(isa (vfun, 'function_handle') || isa (vfun, 'inline'))
     error ('OdePkg:InvalidArgument', ...
       'First input argument must be a valid function handle');
 
@@ -93,50 +93,47 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
     vfunarguments = {};
   end
 
-  %# Start preprocessing, have a look which options have been set in
-  %# vodeoptions. Check if an invalid or unused option has been set and
-  %# print warnings.
-  vslot = vslot(:)';                              %# Create a row vector
-  vinit = vinit(:)';                              %# Create a row vector
-  if (length (vslot) > 2), vstepsizegiven = true; %# Step size checking
-  else vstepsizegiven = false; end  
+  %# Start preprocessing, have a look which options are set in
+  %# vodeoptions, check if an invalid or unused option is set
+  vslot = vslot(:).';     %# Create a row vector
+  vinit = vinit(:).';     %# Create a row vector
+  if (length (vslot) > 2) %# Step size checking
+    vstepsizefixed = true;
+  else
+    vstepsizefixed = false;
+  end  
 
   %# Get the default options that can be set with 'odeset' temporarily
   vodetemp = odeset;
 
   %# Implementation of the option RelTol has been finished. This option
   %# can be set by the user to another value than default value.
-  if (isempty (vodeoptions.RelTol) && ~vstepsizegiven)
+  if (isempty (vodeoptions.RelTol) && ~vstepsizefixed)
     vodeoptions.RelTol = 1e-6;
-    warning ('OdePkg:InvalidOption', ...
+    warning ('OdePkg:InvalidArgument', ...
       'Option "RelTol" not set, new value %f is used', vodeoptions.RelTol);
-  elseif (~isempty (vodeoptions.RelTol) && vstepsizegiven)
-    warning ('OdePkg:InvalidOption', ...
+  elseif (~isempty (vodeoptions.RelTol) && vstepsizefixed)
+    warning ('OdePkg:InvalidArgument', ...
       'Option "RelTol" will be ignored if fixed time stamps are given');
-  %# This implementation has been added to odepkg_structure_check.m
-  %# elseif (~isscalar (vodeoptions.RelTol) && ~vstepsizegiven)
-  %# error ('OdePkg:InvalidOption', ...
-  %#   'Option "RelTol" must be set to a scalar value for this solver');
   end
 
   %# Implementation of the option AbsTol has been finished. This option
   %# can be set by the user to another value than default value.
-  if (isempty (vodeoptions.AbsTol) && ~vstepsizegiven)
+  if (isempty (vodeoptions.AbsTol) && ~vstepsizefixed)
     vodeoptions.AbsTol = 1e-6;
-    warning ('OdePkg:InvalidOption', ...
+    warning ('OdePkg:InvalidArgument', ...
       'Option "AbsTol" not set, new value %f is used', vodeoptions.AbsTol);
-  elseif (~isempty (vodeoptions.AbsTol) && vstepsizegiven)
-    warning ('OdePkg:InvalidOption', ...
+  elseif (~isempty (vodeoptions.AbsTol) && vstepsizefixed)
+    warning ('OdePkg:InvalidArgument', ...
       'Option "AbsTol" will be ignored if fixed time stamps are given');
-  else %# create column vector
-    vodeoptions.AbsTol = vodeoptions.AbsTol(:);
+  else
+    vodeoptions.AbsTol = vodeoptions.AbsTol(:); %# Create column vector
   end
 
   %# Implementation of the option NormControl has been finished. This
   %# option can be set by the user to another value than default value.
-  if (strcmp (vodeoptions.NormControl, 'on')), vnormcontrol = true;
-  else vnormcontrol = false;
-  end
+  if (strcmp (vodeoptions.NormControl, 'on')) vnormcontrol = true;
+  else vnormcontrol = false; end
 
   %# Implementation of the option NonNegative has been finished. This
   %# option can be set by the user to another value than default value.
@@ -144,7 +141,7 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
     if (isempty (vodeoptions.Mass)), vhavenonnegative = true;
     else
       vhavenonnegative = false;
-      warning ('OdePkg:InvalidOption', ...
+      warning ('OdePkg:InvalidArgument', ...
         'Option "NonNegative" will be ignored if mass matrix is set');
     end
   else vhavenonnegative = false;
@@ -164,9 +161,14 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
   if (~isempty (vodeoptions.OutputSel)), vhaveoutputselection = true;
   else vhaveoutputselection = false; end
 
+  %# Implementation of the option OutputSave has been finished. This
+  %# option can be set by the user to another value than default value.
+  if (isempty (vodeoptions.OutputSave)), vodeoptions.OutputSave = 1;
+  end
+
   %# Implementation of the option Refine has been finished. This option
   %# can be set by the user to another value than default value.
-  if (isequal (vodeoptions.Refine, vodetemp.Refine)), vhaverefine = true;
+  if (vodeoptions.Refine > 0), vhaverefine = true;
   else vhaverefine = false; end
 
   %# Implementation of the option Stats has been finished. This option
@@ -174,19 +176,18 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
 
   %# Implementation of the option InitialStep has been finished. This
   %# option can be set by the user to another value than default value.
-  if (isempty (vodeoptions.InitialStep) && ~vstepsizegiven)
-    vodeoptions.InitialStep = abs (vslot(1,1) - vslot(1,2)) / 10;
+  if (isempty (vodeoptions.InitialStep) && ~vstepsizefixed)
+    vodeoptions.InitialStep = (vslot(1,2) - vslot(1,1)) / 10;
     vodeoptions.InitialStep = vodeoptions.InitialStep / 10^vodeoptions.Refine;
-    warning ('OdePkg:InvalidOption', ...
+    warning ('OdePkg:InvalidArgument', ...
       'Option "InitialStep" not set, new value %f is used', vodeoptions.InitialStep);
   end
 
   %# Implementation of the option MaxStep has been finished. This option
   %# can be set by the user to another value than default value.
-  if (isempty (vodeoptions.MaxStep) && ~vstepsizegiven)
-    vodeoptions.MaxStep = abs (vslot(1,1) - vslot(1,length (vslot))) / 10;
-    %# vodeoptions.MaxStep = vodeoptions.MaxStep / 10^vodeoptions.Refine;
-    warning ('OdePkg:InvalidOption', ...
+  if (isempty (vodeoptions.MaxStep) && ~vstepsizefixed)
+    vodeoptions.MaxStep = (vslot(1,2) - vslot(1,1)) / 10;
+    warning ('OdePkg:InvalidArgument', ...
       'Option "MaxStep" not set, new value %f is used', vodeoptions.MaxStep);
   end
 
@@ -199,15 +200,15 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
   %# by this solver because this solver uses an explicit Runge-Kutta
   %# method and therefore no Jacobian calculation is necessary
   if (~isequal (vodeoptions.Jacobian, vodetemp.Jacobian))
-    warning ('OdePkg:InvalidOption', ...
+    warning ('OdePkg:InvalidArgument', ...
       'Option "Jacobian" will be ignored by this solver');
   end
   if (~isequal (vodeoptions.JPattern, vodetemp.JPattern))
-    warning ('OdePkg:InvalidOption', ...
+    warning ('OdePkg:InvalidArgument', ...
       'Option "JPattern" will be ignored by this solver');
   end
   if (~isequal (vodeoptions.Vectorized, vodetemp.Vectorized))
-    warning ('OdePkg:InvalidOption', ...
+    warning ('OdePkg:InvalidArgument', ...
       'Option "Vectorized" will be ignored by this solver');
   end
 
@@ -232,23 +233,23 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
   %# Other options that are not used by this solver. Print a warning
   %# message to tell the user that the option(s) is/are ignored.
   if (~isequal (vodeoptions.MvPattern, vodetemp.MvPattern))
-    warning ('OdePkg:InvalidOption', ...
+    warning ('OdePkg:InvalidArgument', ...
       'Option "MvPattern" will be ignored by this solver');
   end
   if (~isequal (vodeoptions.MassSingular, vodetemp.MassSingular))
-    warning ('OdePkg:InvalidOption', ...
+    warning ('OdePkg:InvalidArgument', ...
       'Option "MassSingular" will be ignored by this solver');
   end
   if (~isequal (vodeoptions.InitialSlope, vodetemp.InitialSlope))
-    warning ('OdePkg:InvalidOption', ...
+    warning ('OdePkg:InvalidArgument', ...
       'Option "InitialSlope" will be ignored by this solver');
   end
   if (~isequal (vodeoptions.MaxOrder, vodetemp.MaxOrder))
-    warning ('OdePkg:InvalidOption', ...
+    warning ('OdePkg:InvalidArgument', ...
       'Option "MaxOrder" will be ignored by this solver');
   end
   if (~isequal (vodeoptions.BDF, vodetemp.BDF))
-    warning ('OdePkg:InvalidOption', ...
+    warning ('OdePkg:InvalidArgument', ...
       'Option "BDF" will be ignored by this solver');
   end
 
@@ -256,13 +257,14 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
   vtimestamp  = vslot(1,1);           %# timestamp = start time
   vtimelength = length (vslot);       %# length needed if fixed steps
   vtimestop   = vslot(1,vtimelength); %# stop time = last value
+  vdirection  = sign (vtimestop);     %# Flag for direction to solve
 
-  if (~vstepsizegiven)
+  if (~vstepsizefixed)
     vstepsize = vodeoptions.InitialStep;
     vminstepsize = (vtimestop - vtimestamp) / (1/eps);
   else %# If step size is given then use the fixed time steps
-    vstepsize = abs (vslot(1,1) - vslot(1,2));
-    vminstepsize = eps; %# vslot(1,2) - vslot(1,1) - eps;
+    vstepsize = vslot(1,2) - vslot(1,1);
+    vminstepsize = sign (vstepsize) * eps;
   end
 
   vretvaltime = vtimestamp; %# first timestamp output
@@ -273,14 +275,14 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
 
   %# Initialize the OutputFcn
   if (vhaveoutputfunction)
-    feval (vodeoptions.OutputFcn, vslot', ...
-      vretvalresult', 'init', vfunarguments{:});
+    feval (vodeoptions.OutputFcn, vslot.', ...
+      vretvalresult.', 'init', vfunarguments{:});
   end
 
   %# Initialize the EventFcn
   if (vhaveeventfunction)
     odepkg_event_handle (vodeoptions.Events, vtimestamp, ...
-      vretvalresult', 'init', vfunarguments{:});
+      vretvalresult.', 'init', vfunarguments{:});
   end
 
   vpow = 1/5;                %# 20071016, reported by Luis Randez
@@ -296,18 +298,22 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
   vc = sum (va, 2);
 
   %# The solver main loop - stop if the endpoint has been reached
-  vcntloop = 2; vcntcycles = 1; vu = vinit; vk = vu' * zeros(1,6);
-  vcntiter = 0; vunhandledtermination = true;
-  while ((vtimestamp < vtimestop && vstepsize >= vminstepsize))
+  vcntloop = 2; vcntcycles = 1; vu = vinit; vk = vu.' * zeros(1,6);
+  vcntiter = 0; vunhandledtermination = true; vcntsave = 2;
+  while ((vdirection * (vtimestamp) < vdirection * (vtimestop)) && ...
+         (vdirection * (vstepsize) >= vdirection * (vminstepsize)))
 
     %# Hit the endpoint of the time slot exactely
-    if ((vtimestamp + vstepsize) > vtimestop)
-      vstepsize = vtimestop - vtimestamp; end
+    if ((vtimestamp + vstepsize) > vdirection * vtimestop)
+%# if (((vtimestamp + vstepsize) > vtimestop) || ...
+%#   (abs(vtimestamp + vstepsize - vtimestop) < eps))
+      vstepsize = vtimestop - vdirection * vtimestamp;
+    end
 
     %# Estimate the six results when using this solver
     for j = 1:6
       vthetime  = vtimestamp + vc(j,1) * vstepsize;
-      vtheinput = vu' + vstepsize * vk(:,1:j-1) * va(j,1:j-1)';
+      vtheinput = vu.' + vstepsize * vk(:,1:j-1) * va(j,1:j-1).';
       if (vhavemasshandle)   %# Handle only the dynamic mass matrix,
         if (vmassdependence) %# constant mass matrices have already
           vmass = feval ...  %# been set before (if any)
@@ -325,8 +331,8 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
     end
 
     %# Compute the 4th and the 5th order estimation
-    y4 = vu' + vstepsize * (vk * vb4);
-    y5 = vu' + vstepsize * (vk * vb5);
+    y4 = vu.' + vstepsize * (vk * vb4);
+    y5 = vu.' + vstepsize * (vk * vb5);
     if (vhavenonnegative)
       vu(vodeoptions.NonNegative) = abs (vu(vodeoptions.NonNegative));
       y4(vodeoptions.NonNegative) = abs (y4(vodeoptions.NonNegative));
@@ -335,49 +341,62 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
     vSaveVUForRefine = vu;
 
     %# Calculate the absolute local truncation error and the acceptable error
-    if (~vstepsizegiven)
+    if (~vstepsizefixed)
       if (~vnormcontrol)
-        vdelta = y5 - y4;
-        vtau = max (vodeoptions.RelTol * vu', vodeoptions.AbsTol);
+        vdelta = abs (y5 - y4);
+        vtau = max (vodeoptions.RelTol * abs (vu.'), vodeoptions.AbsTol);
       else
         vdelta = norm (y5 - y4, Inf);
-        vtau = max (vodeoptions.RelTol * max (norm (vu', Inf), 1.0), ...
+        vtau = max (vodeoptions.RelTol * max (norm (vu.', Inf), 1.0), ...
                     vodeoptions.AbsTol);
       end
-    else %# if (vstepsizegiven == true)
+    else %# if (vstepsizefixed == true)
       vdelta = 1; vtau = 2;
     end
 
     %# If the error is acceptable then update the vretval variables
     if (all (vdelta <= vtau))
       vtimestamp = vtimestamp + vstepsize;
-      vu = y5'; %# MC2001: the higher order estimation as "local extrapolation"
-      vretvaltime(vcntloop,:) = vtimestamp;
-      if (vhaveoutputselection)
-        vretvalresult(vcntloop,:) = vu(vodeoptions.OutputSel);
-      else
-        vretvalresult(vcntloop,:) = vu;
-      end
+      vu = y5.'; %# MC2001: the higher order estimation as "local extrapolation"
+      %# Save the solution every vodeoptions.OutputSave steps             
+      if (mod (vcntloop-1,vodeoptions.OutputSave) == 0)             
+        if (vhaveoutputselection)
+          vretvaltime(vcntsave,:) = vtimestamp;
+          vretvalresult(vcntsave,:) = vu(vodeoptions.OutputSel);
+        else
+          vretvaltime(vcntsave,:) = vtimestamp;
+          vretvalresult(vcntsave,:) = vu;
+        end
+        vcntsave = vcntsave + 1;    
+      end     
       vcntloop = vcntloop + 1; vcntiter = 0;
 
       %# Call plot only if a valid result has been found, therefore this
       %# code fragment has moved here. Stop integration if plot function
       %# returns false
       if (vhaveoutputfunction)
-        if (vhaverefine)                  %# Do interpolation
-          for vcnt = 0:vodeoptions.Refine %# Approximation between told and t
+        for vcnt = 0:vodeoptions.Refine %# Approximation between told and t
+          if (vhaverefine)              %# Do interpolation
             vapproxtime = (vcnt + 1) * vstepsize / (vodeoptions.Refine + 2);
-            vapproxvals = vSaveVUForRefine' + vapproxtime * (vk * vb5);
-            if (vhaveoutputselection)
-              vapproxvals = vapproxvals(vodeoptions.OutputSel);
-            end
-            feval (vodeoptions.OutputFcn, (vtimestamp - vstepsize) + vapproxtime, ...
-              vapproxvals, [], vfunarguments{:});
+            vapproxvals = vSaveVUForRefine.' + vapproxtime * (vk * vb5);
+            vapproxtime = (vtimestamp - vstepsize) + vapproxtime;
+          else
+            vapproxvals = vu.';
+            vapproxtime = vtimestamp;
           end
+          if (vhaveoutputselection)
+            vapproxvals = vapproxvals(vodeoptions.OutputSel);
+          end          
+          vpltret = feval (vodeoptions.OutputFcn, vapproxtime, ...
+            vapproxvals, [], vfunarguments{:});          
+          if vpltret %# Leave refinement loop
+            break;
+          end         
+        end
+        if (vpltret) %# Leave main loop
+          vunhandledtermination = false;
+          break;
         end
-        vpltret = feval (vodeoptions.OutputFcn, vtimestamp, ...
-          vretvalresult(vcntloop-1,:)', [], vfunarguments{:});
-        if (vpltret), vunhandledtermination = false; break; end
       end
 
       %# Call event only if a valid result has been found, therefore this
@@ -396,19 +415,34 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
     end %# If the error is acceptable ...
 
     %# Update the step size for the next integration step
-    if (~vstepsizegiven)
-      %# vdelta may be 0 or even negative - could be an iteration problem
-      vdelta = max (vdelta, eps); 
-      vstepsize = min (vodeoptions.MaxStep, ...
-        min (0.8 * vstepsize * (vtau ./ vdelta) .^ vpow));
-    elseif (vstepsizegiven)
-      if (vcntloop < vtimelength)
-        vstepsize = vslot(1,vcntloop-1) - vslot(1,vcntloop-2);
+    if (~vstepsizefixed)
+      %# 20080425, reported by Marco Caliari
+      %# vdelta cannot be negative (because of the absolute value that
+      %# has been introduced) but it could be 0, then replace the zeros 
+      %# with the maximum value of vdelta
+      vdelta(find (vdelta == 0)) = max (vdelta);
+      %# It could happen that max (vdelta) == 0 (ie. that the original
+      %# vdelta was 0), in that case we double the previous vstepsize
+      vdelta(find (vdelta == 0)) = max (vtau) .* (0.4 ^ (1 / vpow));
+
+      if (vdirection == 1)
+        vstepsize = min (vodeoptions.MaxStep, ...
+           min (0.8 * vstepsize * (vtau ./ vdelta) .^ vpow));
+      else
+        vstepsize = max (vodeoptions.MaxStep, ...
+          max (0.8 * vstepsize * (vtau ./ vdelta) .^ vpow));
+      end
+
+    else %# if (vstepsizefixed)
+      if (vcntloop <= vtimelength)
+        vstepsize = vslot(vcntloop) - vslot(vcntloop-1);
+      else %# Get out of the main integration loop
+        break;
       end
     end
 
     %# Update counters that count the number of iteration cycles
-    vcntcycles = vcntcycles + 1; %# Needed for postprocessing
+    vcntcycles = vcntcycles + 1; %# Needed for cost statistics
     vcntiter = vcntiter + 1;     %# Needed to find iteration problems
 
     %# Stop solving because the last 1000 steps no successful valid
@@ -425,16 +459,17 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
   end %# The main loop
 
   %# Check if integration of the ode has been successful
-  if (vtimestamp < vtimestop)
+  if (vdirection * vtimestamp < vdirection * vtimestop)
     if (vunhandledtermination == true)
-      error (['Solving has not been successful. The iterative', ...
-        ' integration loop exited at time t = %f', ...
-        ' before endpoint at tend = %f was reached. This may', ...
-        ' happen if the stepsize grows smaller than defined in', ...
-        ' vminstepsize. Try to reduce the value of "InitialStep" and/or', ...
-        ' "MaxStep" with the command "odeset".\n'], vtimestamp, vtimestop);
+      error ('OdePkg:InvalidArgument', ...
+        ['Solving has not been successful. The iterative', ...
+         ' integration loop exited at time t = %f', ...
+         ' before endpoint at tend = %f was reached. This may', ...
+         ' happen if the stepsize grows smaller than defined in', ...
+         ' vminstepsize. Try to reduce the value of "InitialStep" and/or', ...
+         ' "MaxStep" with the command "odeset".\n'], vtimestamp, vtimestop);
     else
-      warning ('OdePkg:HideWarning', ...
+      warning ('OdePkg:InvalidArgument', ...
         ['Solver has been stopped by a call of "break" in', ...
          ' the main iteration loop at time t = %f before endpoint at', ...
          ' tend = %f was reached. This may happen because the @odeplot', ...
@@ -446,12 +481,17 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
   %# Postprocessing, do whatever when terminating integration algorithm
   if (vhaveoutputfunction) %# Cleanup plotter
     feval (vodeoptions.OutputFcn, vtimestamp, ...
-      vretvalresult(vcntloop-1,:)', 'done', vfunarguments{:});
+      vu.', 'done', vfunarguments{:});
   end
   if (vhaveeventfunction)  %# Cleanup event function handling
     odepkg_event_handle (vodeoptions.Events, vtimestamp, ...
-      vretvalresult(vcntloop-1,:), 'done', vfunarguments{:});
+      vu.', 'done', vfunarguments{:});
   end
+  %# Save the last step, if not already saved
+  if (mod (vcntloop-2,vodeoptions.OutputSave) ~= 0)
+    vretvaltime(vcntsave,:) = vtimestamp;
+    vretvalresult(vcntsave,:) = vu;
+  end 
 
   %# Print additional information if option Stats is set
   if (strcmp (vodeoptions.Stats, 'on'))
@@ -468,7 +508,8 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
       vmsg = fprintf (1, 'Number of failed attempts:  %d', vnfailed);
       vmsg = fprintf (1, 'Number of function calls:   %d', vnfevals);
     end
-  else vhavestats = false;
+  else
+    vhavestats = false;
   end
 
   if (nargout == 1)                 %# Sort output variables, depends on nargout
@@ -503,8 +544,8 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
       varargout{4} = vevent{4};     %# Results when an event occured
       varargout{5} = vevent{2};     %# Index info which event occured
     end
-  %# else nothing will be returned, varargout{1} undefined
   end
+end
 
 %! # We are using the "Van der Pol" implementation for all tests that
 %! # are done for this function. We also define a Jacobian, Events,
@@ -525,10 +566,10 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
 %!  vtrm = ones (2,1);              %# that's why component 2
 %!  vdir = ones (2,1);              %# seems to not be exact
 %!function [vmas] = fmas (vt, vy)
-%!  vmas =  [1, 0; 0, 1];     %# Dummy mass matrix for tests
+%!  vmas = [1, 0; 0, 1];            %# Dummy mass matrix for tests
 %!function [vmas] = fmsa (vt, vy)
-%!  vmas = sparse ([1, 0; 0, 1]); %# A sparse dummy matrix
-%!function [vref] = fref ()   %# The computed reference solut
+%!  vmas = sparse ([1, 0; 0, 1]);   %# A sparse dummy matrix
+%!function [vref] = fref ()         %# The computed reference sol
 %!  vref = [0.32331666704577, -1.83297456798624];
 %!function [vout] = fout (vt, vy, vflag, varargin)
 %!  if (regexp (char (vflag), 'init') == 1)
@@ -544,7 +585,7 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
 %! %# Turn off output of warning messages for all tests, turn them on
 %! %# again if the last test is called
 %!error %# input argument number one
-%!  warning ('off', 'OdePkg:InvalidOption');
+%!  warning ('off', 'OdePkg:InvalidArgument');
 %!  B = ode45 (1, [0 25], [3 15 1]);
 %!error %# input argument number two
 %!  B = ode45 (@fpol, 1, [3 15 1]);
@@ -576,6 +617,18 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
 %!error %# strange OdePkg structure
 %!  vopt = struct ('foo', 1);
 %!  vsol = ode45 (@fpol, [0 2], [2 0], vopt);
+%!test %# Solve vdp in fixed step sizes
+%!  vsol = ode45 (@fpol, [0:0.1:2], [2 0]);
+%!  assert (vsol.x(:), [0:0.1:2]');
+%!  assert (vsol.y(end,:), fref, 1e-3);
+%!test %# Solve in backward direction starting at t=0
+%! %# vref = [-1.2054034414, 0.9514292694];
+%!  vsol = ode45 (@fpol, [0 -2], [2 0]);
+%! %# assert ([vsol.x(end), vsol.y(end,:)], [-2, fref], 1e-3);
+%!test %# Solve in backward direction starting at t=2
+%! %#  vref = [-1.2154183302, 0.9433018000];
+%!  vsol = ode45 (@fpol, [2 -2], [0.3233166627 -1.8329746843]);
+%! %#  assert ([vsol.x(end), vsol.y(end,:)], [-2, fref], 1e-3);
 %!test %# AbsTol option
 %!  vopt = odeset ('AbsTol', 1e-5);
 %!  vsol = ode45 (@fpol, [0 2], [2 0], vopt);
@@ -595,6 +648,12 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
 %!test %# Details of OutputSel and Refine can't be tested
 %!  vopt = odeset ('OutputFcn', @fout, 'OutputSel', 1, 'Refine', 5);
 %!  vsol = ode45 (@fpol, [0 2], [2 0], vopt);
+%!test %# Details of OutputSave can't be tested
+%!  vopt = odeset ('OutputSave', 1, 'OutputSel', 1);
+%!  vsla = ode45 (@fpol, [0 2], [2 0], vopt);
+%!  vopt = odeset ('OutputSave', 2);
+%!  vslb = ode45 (@fpol, [0 2], [2 0], vopt);
+%!  assert (length (vsla.x) > length (vslb.x))
 %!test %# Stats must add further elements in vsol
 %!  vopt = odeset ('Stats', 'on');
 %!  vsol = ode45 (@fpol, [0 2], [2 0], vopt);
@@ -616,7 +675,6 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
 %!  assert (isfield (vsol, 'xe'));
 %!  assert (isfield (vsol, 'ye'));
 %!test %# Events option, now stop integration
-%!  warning ('off', 'OdePkg:HideWarning');
 %!  vopt = odeset ('Events', @fevn, 'NormControl', 'on');
 %!  vsol = ode45 (@fpol, [0 10], [2 0], vopt);
 %!  assert ([vsol.ie, vsol.xe, vsol.ye], ...
@@ -625,8 +683,7 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
 %!  vopt = odeset ('Events', @fevn, 'NormControl', 'on');
 %!  [vt, vy, vxe, vye, vie] = ode45 (@fpol, [0 10], [2 0], vopt);
 %!  assert ([vie, vxe, vye], ...
-%!    [2.0, 2.496110, -0.830550, -2.677589], .5e-1);
-%!  warning ('on', 'OdePkg:HideWarning');
+%!    [2.0, 2.496110, -0.830550, -2.677589], 1e-1);
 %!test %# Jacobian option
 %!  vopt = odeset ('Jacobian', @fjac);
 %!  vsol = ode45 (@fpol, [0 2], [2 0], vopt);
@@ -665,8 +722,9 @@ function [varargout] = ode45 (vfun, vslot, vinit, varargin)
 %! %# test for MaxOrder option is missing
 %! %# test for BDF option is missing
 %!
-%!  warning ('on', 'OdePkg:InvalidOption');
+%!  warning ('on', 'OdePkg:InvalidArgument');
 
 %# Local Variables: ***
 %# mode: octave ***
 %# End: ***
+
