@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2007-2008, Thomas Treichl <treichl@users.sourceforge.net>
-OdePkg - Package for solving ordinary differential equations with this software
+OdePkg - A package for solving ordinary differential equations and more
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ typedef octave_idx_type (*odepkg_seulex_soltype)
 extern "C" {
   F77_RET_T F77_FUNC (seulex, SEULEX)
     (const octave_idx_type& N, odepkg_seulex_usrtype, const octave_idx_type& IFCN,
-     const octave_idx_type& X, const double* Y, const double& XEND,
+     const double& X, const double* Y, const double& XEND,
      const double& H, const double* RTOL, const double* ATOL,
      const octave_idx_type& ITOL, odepkg_seulex_jactype, const octave_idx_type& IJAC,
      const octave_idx_type& MLJAC, const octave_idx_type& MUJAC, odepkg_seulex_masstype,
@@ -104,8 +104,8 @@ octave_idx_type odepkg_seulex_usrfcn
   ColumnVector A(N);
   for (octave_idx_type vcnt = 0; vcnt < N; vcnt++) {
     A(vcnt) = Y[vcnt];
-    //    octave_stdout << "bin hier Y[" << vcnt << "] " << Y[vcnt] << std::endl;
-    //    octave_stdout << "bin hier T " << X << std::endl;
+    //    octave_stdout << "I am here Y[" << vcnt << "] " << Y[vcnt] << std::endl;
+    //    octave_stdout << "I am here T " << X << std::endl;
   }
 
   // Fill the variable for the input arguments before evaluating the
@@ -136,7 +136,6 @@ octave_idx_type odepkg_seulex_jacfcn
   ColumnVector A(N);
   for (octave_idx_type vcnt = 0; vcnt < N; vcnt++)
     A(vcnt) = Y[vcnt];
-  // octave_stdout << "bin drinne" << std::endl;
 
   // Set the values that are needed as input arguments before calling
   // the Jacobian function and then call the Jacobian interface
@@ -260,7 +259,7 @@ DEFUN_DLD (odesx, args, nargout,
 @deftypefnx {Command} {[@var{sol}] =} odesx (@var{@@fun}, @var{slot}, @var{init}, [@var{opt}], [@var{par1}, @var{par2}, @dots{}])\n\
 @deftypefnx {Command} {[@var{t}, @var{y}, [@var{xe}, @var{ye}, @var{ie}]] =} odesx (@var{@@fun}, @var{slot}, @var{init}, [@var{opt}], [@var{par1}, @var{par2}, @dots{}])\n\
 \n\
-This function file can be used to solve a set of stiff or non--stiff ordinary differential equations (ODEs) and non--stiff or stiff differential algebraic equations (DAEs). This function file is a wrapper to Hairer's and Wanner's Fortran solver @file{seulex.f}.\n\
+This function file can be used to solve a set of stiff ordinary differential equations (ODEs) and stiff differential algebraic equations (DAEs). This function file is a wrapper to Hairer's and Wanner's Fortran solver @file{seulex.f}.\n\
 \n\
 If this function is called with no return argument then plot the solution over time in a figure window while solving the set of ODEs that are defined in a function and specified by the function handle @var{@@fun}. The second input argument @var{slot} is a double vector that defines the time slot, @var{init} is a double vector that defines the initial values of the states, @var{opt} can optionally be a structure array that keeps the options created with the command @command{odeset} and @var{par1}, @var{par2}, @dots{} can optionally be other input arguments of any type that have to be passed to the function defined by @var{@@fun}.\n\
 \n\
@@ -573,10 +572,10 @@ odesx (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   octave_idx_type MUMAS=N;
   octave_idx_type IOUT = 1; // The SOLOUT function will always be called
   octave_idx_type LWORK = N*(N+N+N+12+8)+4*12+20+(2+12*(12+3)/2)*N;
-  double WORK[LWORK];
+  OCTAVE_LOCAL_BUFFER (double, WORK, LWORK);
   for (octave_idx_type vcnt = 0; vcnt < LWORK; vcnt++) WORK[vcnt] = 0.0;
   octave_idx_type LIWORK = 2*N+12+20+N;
-  octave_idx_type IWORK[LIWORK];
+  OCTAVE_LOCAL_BUFFER (octave_idx_type, IWORK, LIWORK);
   for (octave_idx_type vcnt = 0; vcnt < LIWORK; vcnt++) IWORK[vcnt] = 0;
   double RPAR[1] = {0.0};
   octave_idx_type IPAR[1] = {0};
